@@ -408,6 +408,19 @@ class BuilderVisitor(ast.NodeVisitor):
     def visit_Str(self, py_node):
         return py_node.s, self.scope, None
 
+    def visit_Constant(self, py_node):
+        # Added in Python 3.6+
+        # Replaces visit_Str, etc.
+        # This code is ugly to be compatible with Python 2.7
+        value = py_node.value
+        type_name = type(value).__name__
+        # We have to duplicate code because methods are decorated...
+        # Calling decorated method would `builder.add_child()` twice.
+        if type_name in ('bool', 'NoneType', 'int', 'float', 'complex',
+                         'str', 'bytes', 'ellipsis'):
+            return value, self.scope, None
+        return self.generic_visit(node)
+
     def visit_Subscript(self, py_node):
         return py_model.PyDummyExpr(self.scope, self.parent), self.scope, None
 
@@ -431,3 +444,4 @@ class BuilderVisitor(ast.NodeVisitor):
 
     def visit_Yield(self, py_node):
         return py_model.PyDummyExpr(self.scope, self.parent), self.scope, None
+
